# Oneary

Merge your multi-format Sonarr/Radarr libraries into one.

# Usage 

```
usage: oneary [-h] [-d] [-v]

options:
  -h, --help     show this help message and exit
  -d, --debug    shows debug info, useful for testing
  -v, --version  show current version and exit
```
